# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.protobuf import duration_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={"ImagePayload", "TextPayload", "VideoThumbnail", "VideoPayload",},
)


class ImagePayload(proto.Message):
    r"""Container of information about an image.
    Attributes:
        mime_type (str):
            Image format.
        image_thumbnail (bytes):
            A byte string of a thumbnail image.
        image_uri (str):
            Image uri from the user bucket.
        signed_uri (str):
            Signed uri of the image file in the service
            bucket.
    """

    mime_type = proto.Field(proto.STRING, number=1,)
    image_thumbnail = proto.Field(proto.BYTES, number=2,)
    image_uri = proto.Field(proto.STRING, number=3,)
    signed_uri = proto.Field(proto.STRING, number=4,)


class TextPayload(proto.Message):
    r"""Container of information about a piece of text.
    Attributes:
        text_content (str):
            Text content.
    """

    text_content = proto.Field(proto.STRING, number=1,)


class VideoThumbnail(proto.Message):
    r"""Container of information of a video thumbnail.
    Attributes:
        thumbnail (bytes):
            A byte string of the video frame.
        time_offset (google.protobuf.duration_pb2.Duration):
            Time offset relative to the beginning of the
            video, corresponding to the video frame where
            the thumbnail has been extracted from.
    """

    thumbnail = proto.Field(proto.BYTES, number=1,)
    time_offset = proto.Field(proto.MESSAGE, number=2, message=duration_pb2.Duration,)


class VideoPayload(proto.Message):
    r"""Container of information of a video.
    Attributes:
        mime_type (str):
            Video format.
        video_uri (str):
            Video uri from the user bucket.
        video_thumbnails (Sequence[google.cloud.datalabeling_v1beta1.types.VideoThumbnail]):
            The list of video thumbnails.
        frame_rate (float):
            FPS of the video.
        signed_uri (str):
            Signed uri of the video file in the service
            bucket.
    """

    mime_type = proto.Field(proto.STRING, number=1,)
    video_uri = proto.Field(proto.STRING, number=2,)
    video_thumbnails = proto.RepeatedField(
        proto.MESSAGE, number=3, message="VideoThumbnail",
    )
    frame_rate = proto.Field(proto.FLOAT, number=4,)
    signed_uri = proto.Field(proto.STRING, number=5,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.datalabeling_v1beta1.types import annotation
from google.cloud.datalabeling_v1beta1.types import data_payloads
from google.cloud.datalabeling_v1beta1.types import (
    human_annotation_config as gcd_human_annotation_config,
)
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={
        "DataType",
        "Dataset",
        "InputConfig",
        "TextMetadata",
        "ClassificationMetadata",
        "GcsSource",
        "BigQuerySource",
        "OutputConfig",
        "GcsDestination",
        "GcsFolderDestination",
        "DataItem",
        "AnnotatedDataset",
        "LabelStats",
        "AnnotatedDatasetMetadata",
        "Example",
    },
)


class DataType(proto.Enum):
    r""""""
    DATA_TYPE_UNSPECIFIED = 0
    IMAGE = 1
    VIDEO = 2
    TEXT = 4
    GENERAL_DATA = 6


class Dataset(proto.Message):
    r"""Dataset is the resource to hold your data. You can request
    multiple labeling tasks for a dataset while each one will
    generate an AnnotatedDataset.

    Attributes:
        name (str):
            Output only. Dataset resource name, format is:
            projects/{project_id}/datasets/{dataset_id}
        display_name (str):
            Required. The display name of the dataset.
            Maximum of 64 characters.
        description (str):
            Optional. User-provided description of the
            annotation specification set. The description
            can be up to 10000 characters long.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time the dataset is created.
        input_configs (Sequence[google.cloud.datalabeling_v1beta1.types.InputConfig]):
            Output only. This is populated with the
            original input configs where ImportData is
            called. It is available only after the clients
            import data to this dataset.
        blocking_resources (Sequence[str]):
            Output only. The names of any related
            resources that are blocking changes to the
            dataset.
        data_item_count (int):
            Output only. The number of data items in the
            dataset.
    """

    name = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)
    description = proto.Field(proto.STRING, number=3,)
    create_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
    input_configs = proto.RepeatedField(proto.MESSAGE, number=5, message="InputConfig",)
    blocking_resources = proto.RepeatedField(proto.STRING, number=6,)
    data_item_count = proto.Field(proto.INT64, number=7,)


class InputConfig(proto.Message):
    r"""The configuration of input data, including data type,
    location, etc.

    Attributes:
        text_metadata (google.cloud.datalabeling_v1beta1.types.TextMetadata):
            Required for text import, as language code
            must be specified.
        gcs_source (google.cloud.datalabeling_v1beta1.types.GcsSource):
            Source located in Cloud Storage.
        bigquery_source (google.cloud.datalabeling_v1beta1.types.BigQuerySource):
            Source located in BigQuery. You must specify this field if
            you are using this InputConfig in an
            [EvaluationJob][google.cloud.datalabeling.v1beta1.EvaluationJob].
        data_type (google.cloud.datalabeling_v1beta1.types.DataType):
            Required. Data type must be specifed when
            user tries to import data.
        annotation_type (google.cloud.datalabeling_v1beta1.types.AnnotationType):
            Optional. The type of annotation to be performed on this
            data. You must specify this field if you are using this
            InputConfig in an
            [EvaluationJob][google.cloud.datalabeling.v1beta1.EvaluationJob].
        classification_metadata (google.cloud.datalabeling_v1beta1.types.ClassificationMetadata):
            Optional. Metadata about annotations for the input. You must
            specify this field if you are using this InputConfig in an
            [EvaluationJob][google.cloud.datalabeling.v1beta1.EvaluationJob]
            for a model version that performs classification.
    """

    text_metadata = proto.Field(
        proto.MESSAGE, number=6, oneof="data_type_metadata", message="TextMetadata",
    )
    gcs_source = proto.Field(
        proto.MESSAGE, number=2, oneof="source", message="GcsSource",
    )
    bigquery_source = proto.Field(
        proto.MESSAGE, number=5, oneof="source", message="BigQuerySource",
    )
    data_type = proto.Field(proto.ENUM, number=1, enum="DataType",)
    annotation_type = proto.Field(proto.ENUM, number=3, enum=annotation.AnnotationType,)
    classification_metadata = proto.Field(
        proto.MESSAGE, number=4, message="ClassificationMetadata",
    )


class TextMetadata(proto.Message):
    r"""Metadata for the text.
    Attributes:
        language_code (str):
            The language of this text, as a
            `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__.
            Default value is en-US.
    """

    language_code = proto.Field(proto.STRING, number=1,)


class ClassificationMetadata(proto.Message):
    r"""Metadata for classification annotations.
    Attributes:
        is_multi_label (bool):
            Whether the classification task is multi-
            abel or not.
    """

    is_multi_label = proto.Field(proto.BOOL, number=1,)


class GcsSource(proto.Message):
    r"""Source of the Cloud Storage file to be imported.
    Attributes:
        input_uri (str):
            Required. The input URI of source file. This must be a Cloud
            Storage path (``gs://...``).
        mime_type (str):
            Required. The format of the source file. Only
            "text/csv" is supported.
    """

    input_uri = proto.Field(proto.STRING, number=1,)
    mime_type = proto.Field(proto.STRING, number=2,)


class BigQuerySource(proto.Message):
    r"""The BigQuery location for input data. If used in an
    [EvaluationJob][google.cloud.datalabeling.v1beta1.EvaluationJob],
    this is where the service saves the prediction input and output
    sampled from the model version.

    Attributes:
        input_uri (str):
            Required. BigQuery URI to a table, up to 2,000 characters
            long. If you specify the URI of a table that does not exist,
            Data Labeling Service creates a table at the URI with the
            correct schema when you create your
            [EvaluationJob][google.cloud.datalabeling.v1beta1.EvaluationJob].
            If you specify the URI of a table that already exists, it
            must have the `correct
            schema </ml-engine/docs/continuous-evaluation/create-job#table-schema>`__.

            Provide the table URI in the following format:

            "bq://{your_project_id}/{your_dataset_name}/{your_table_name}"

            `Learn
            more </ml-engine/docs/continuous-evaluation/create-job#table-schema>`__.
    """

    input_uri = proto.Field(proto.STRING, number=1,)


class OutputConfig(proto.Message):
    r"""The configuration of output data.
    Attributes:
        gcs_destination (google.cloud.datalabeling_v1beta1.types.GcsDestination):
            Output to a file in Cloud Storage. Should be
            used for labeling output other than image
            segmentation.
        gcs_folder_destination (google.cloud.datalabeling_v1beta1.types.GcsFolderDestination):
            Output to a folder in Cloud Storage. Should
            be used for image segmentation labeling output.
    """

    gcs_destination = proto.Field(
        proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
    )
    gcs_folder_destination = proto.Field(
        proto.MESSAGE, number=2, oneof="destination", message="GcsFolderDestination",
    )


class GcsDestination(proto.Message):
    r"""Export destination of the data.Only gcs path is allowed in
    output_uri.

    Attributes:
        output_uri (str):
            Required. The output uri of destination file.
        mime_type (str):
            Required. The format of the gcs destination.
            Only "text/csv" and "application/json"
            are supported.
    """

    output_uri = proto.Field(proto.STRING, number=1,)
    mime_type = proto.Field(proto.STRING, number=2,)


class GcsFolderDestination(proto.Message):
    r"""Export folder destination of the data.
    Attributes:
        output_folder_uri (str):
            Required. Cloud Storage directory to export
            data to.
    """

    output_folder_uri = proto.Field(proto.STRING, number=1,)


class DataItem(proto.Message):
    r"""DataItem is a piece of data, without annotation. For example,
    an image.

    Attributes:
        image_payload (google.cloud.datalabeling_v1beta1.types.ImagePayload):
            The image payload, a container of the image
            bytes/uri.
        text_payload (google.cloud.datalabeling_v1beta1.types.TextPayload):
            The text payload, a container of text
            content.
        video_payload (google.cloud.datalabeling_v1beta1.types.VideoPayload):
            The video payload, a container of the video
            uri.
        name (str):
            Output only. Name of the data item, in format of:
            projects/{project_id}/datasets/{dataset_id}/dataItems/{data_item_id}
    """

    image_payload = proto.Field(
        proto.MESSAGE, number=2, oneof="payload", message=data_payloads.ImagePayload,
    )
    text_payload = proto.Field(
        proto.MESSAGE, number=3, oneof="payload", message=data_payloads.TextPayload,
    )
    video_payload = proto.Field(
        proto.MESSAGE, number=4, oneof="payload", message=data_payloads.VideoPayload,
    )
    name = proto.Field(proto.STRING, number=1,)


class AnnotatedDataset(proto.Message):
    r"""AnnotatedDataset is a set holding annotations for data in a
    Dataset. Each labeling task will generate an AnnotatedDataset
    under the Dataset that the task is requested for.

    Attributes:
        name (str):
            Output only. AnnotatedDataset resource name in format of:
            projects/{project_id}/datasets/{dataset_id}/annotatedDatasets/
            {annotated_dataset_id}
        display_name (str):
            Output only. The display name of the
            AnnotatedDataset. It is specified in
            HumanAnnotationConfig when user starts a
            labeling task. Maximum of 64 characters.
        description (str):
            Output only. The description of the
            AnnotatedDataset. It is specified in
            HumanAnnotationConfig when user starts a
            labeling task. Maximum of 10000 characters.
        annotation_source (google.cloud.datalabeling_v1beta1.types.AnnotationSource):
            Output only. Source of the annotation.
        annotation_type (google.cloud.datalabeling_v1beta1.types.AnnotationType):
            Output only. Type of the annotation. It is
            specified when starting labeling task.
        example_count (int):
            Output only. Number of examples in the
            annotated dataset.
        completed_example_count (int):
            Output only. Number of examples that have
            annotation in the annotated dataset.
        label_stats (google.cloud.datalabeling_v1beta1.types.LabelStats):
            Output only. Per label statistics.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time the AnnotatedDataset was
            created.
        metadata (google.cloud.datalabeling_v1beta1.types.AnnotatedDatasetMetadata):
            Output only. Additional information about
            AnnotatedDataset.
        blocking_resources (Sequence[str]):
            Output only. The names of any related
            resources that are blocking changes to the
            annotated dataset.
    """

    name = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)
    description = proto.Field(proto.STRING, number=9,)
    annotation_source = proto.Field(
        proto.ENUM, number=3, enum=annotation.AnnotationSource,
    )
    annotation_type = proto.Field(proto.ENUM, number=8, enum=annotation.AnnotationType,)
    example_count = proto.Field(proto.INT64, number=4,)
    completed_example_count = proto.Field(proto.INT64, number=5,)
    label_stats = proto.Field(proto.MESSAGE, number=6, message="LabelStats",)
    create_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
    metadata = proto.Field(
        proto.MESSAGE, number=10, message="AnnotatedDatasetMetadata",
    )
    blocking_resources = proto.RepeatedField(proto.STRING, number=11,)


class LabelStats(proto.Message):
    r"""Statistics about annotation specs.
    Attributes:
        example_count (Sequence[google.cloud.datalabeling_v1beta1.types.LabelStats.ExampleCountEntry]):
            Map of each annotation spec's example count.
            Key is the annotation spec name and value is the
            number of examples for that annotation spec. If
            the annotated dataset does not have annotation
            spec, the map will return a pair where the key
            is empty string and value is the total number of
            annotations.
    """

    example_count = proto.MapField(proto.STRING, proto.INT64, number=1,)


class AnnotatedDatasetMetadata(proto.Message):
    r"""Metadata on AnnotatedDataset.
    Attributes:
        image_classification_config (google.cloud.datalabeling_v1beta1.types.ImageClassificationConfig):
            Configuration for image classification task.
        bounding_poly_config (google.cloud.datalabeling_v1beta1.types.BoundingPolyConfig):
            Configuration for image bounding box and
            bounding poly task.
        polyline_config (google.cloud.datalabeling_v1beta1.types.PolylineConfig):
            Configuration for image polyline task.
        segmentation_config (google.cloud.datalabeling_v1beta1.types.SegmentationConfig):
            Configuration for image segmentation task.
        video_classification_config (google.cloud.datalabeling_v1beta1.types.VideoClassificationConfig):
            Configuration for video classification task.
        object_detection_config (google.cloud.datalabeling_v1beta1.types.ObjectDetectionConfig):
            Configuration for video object detection
            task.
        object_tracking_config (google.cloud.datalabeling_v1beta1.types.ObjectTrackingConfig):
            Configuration for video object tracking task.
        event_config (google.cloud.datalabeling_v1beta1.types.EventConfig):
            Configuration for video event labeling task.
        text_classification_config (google.cloud.datalabeling_v1beta1.types.TextClassificationConfig):
            Configuration for text classification task.
        text_entity_extraction_config (google.cloud.datalabeling_v1beta1.types.TextEntityExtractionConfig):
            Configuration for text entity extraction
            task.
        human_annotation_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            HumanAnnotationConfig used when requesting
            the human labeling task for this
            AnnotatedDataset.
    """

    image_classification_config = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.ImageClassificationConfig,
    )
    bounding_poly_config = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.BoundingPolyConfig,
    )
    polyline_config = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.PolylineConfig,
    )
    segmentation_config = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.SegmentationConfig,
    )
    video_classification_config = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.VideoClassificationConfig,
    )
    object_detection_config = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.ObjectDetectionConfig,
    )
    object_tracking_config = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.ObjectTrackingConfig,
    )
    event_config = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.EventConfig,
    )
    text_classification_config = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.TextClassificationConfig,
    )
    text_entity_extraction_config = proto.Field(
        proto.MESSAGE,
        number=11,
        oneof="annotation_request_config",
        message=gcd_human_annotation_config.TextEntityExtractionConfig,
    )
    human_annotation_config = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcd_human_annotation_config.HumanAnnotationConfig,
    )


class Example(proto.Message):
    r"""An Example is a piece of data and its annotation. For
    example, an image with label "house".

    Attributes:
        image_payload (google.cloud.datalabeling_v1beta1.types.ImagePayload):
            The image payload, a container of the image
            bytes/uri.
        text_payload (google.cloud.datalabeling_v1beta1.types.TextPayload):
            The text payload, a container of the text
            content.
        video_payload (google.cloud.datalabeling_v1beta1.types.VideoPayload):
            The video payload, a container of the video
            uri.
        name (str):
            Output only. Name of the example, in format of:
            projects/{project_id}/datasets/{dataset_id}/annotatedDatasets/
            {annotated_dataset_id}/examples/{example_id}
        annotations (Sequence[google.cloud.datalabeling_v1beta1.types.Annotation]):
            Output only. Annotations for the piece of
            data in Example. One piece of data can have
            multiple annotations.
    """

    image_payload = proto.Field(
        proto.MESSAGE, number=2, oneof="payload", message=data_payloads.ImagePayload,
    )
    text_payload = proto.Field(
        proto.MESSAGE, number=6, oneof="payload", message=data_payloads.TextPayload,
    )
    video_payload = proto.Field(
        proto.MESSAGE, number=7, oneof="payload", message=data_payloads.VideoPayload,
    )
    name = proto.Field(proto.STRING, number=1,)
    annotations = proto.RepeatedField(
        proto.MESSAGE, number=5, message=annotation.Annotation,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.datalabeling_v1beta1.types import dataset as gcd_dataset
from google.cloud.datalabeling_v1beta1.types import human_annotation_config
from google.protobuf import timestamp_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={
        "ImportDataOperationResponse",
        "ExportDataOperationResponse",
        "ImportDataOperationMetadata",
        "ExportDataOperationMetadata",
        "LabelOperationMetadata",
        "LabelImageClassificationOperationMetadata",
        "LabelImageBoundingBoxOperationMetadata",
        "LabelImageOrientedBoundingBoxOperationMetadata",
        "LabelImageBoundingPolyOperationMetadata",
        "LabelImagePolylineOperationMetadata",
        "LabelImageSegmentationOperationMetadata",
        "LabelVideoClassificationOperationMetadata",
        "LabelVideoObjectDetectionOperationMetadata",
        "LabelVideoObjectTrackingOperationMetadata",
        "LabelVideoEventOperationMetadata",
        "LabelTextClassificationOperationMetadata",
        "LabelTextEntityExtractionOperationMetadata",
        "CreateInstructionMetadata",
    },
)


class ImportDataOperationResponse(proto.Message):
    r"""Response used for ImportData longrunning operation.
    Attributes:
        dataset (str):
            Ouptut only. The name of imported dataset.
        total_count (int):
            Output only. Total number of examples
            requested to import
        import_count (int):
            Output only. Number of examples imported
            successfully.
    """

    dataset = proto.Field(proto.STRING, number=1,)
    total_count = proto.Field(proto.INT32, number=2,)
    import_count = proto.Field(proto.INT32, number=3,)


class ExportDataOperationResponse(proto.Message):
    r"""Response used for ExportDataset longrunning operation.
    Attributes:
        dataset (str):
            Ouptut only. The name of dataset. "projects/*/datasets/*".
        total_count (int):
            Output only. Total number of examples
            requested to export
        export_count (int):
            Output only. Number of examples exported
            successfully.
        label_stats (google.cloud.datalabeling_v1beta1.types.LabelStats):
            Output only. Statistic infos of labels in the
            exported dataset.
        output_config (google.cloud.datalabeling_v1beta1.types.OutputConfig):
            Output only. output_config in the ExportData request.
    """

    dataset = proto.Field(proto.STRING, number=1,)
    total_count = proto.Field(proto.INT32, number=2,)
    export_count = proto.Field(proto.INT32, number=3,)
    label_stats = proto.Field(proto.MESSAGE, number=4, message=gcd_dataset.LabelStats,)
    output_config = proto.Field(
        proto.MESSAGE, number=5, message=gcd_dataset.OutputConfig,
    )


class ImportDataOperationMetadata(proto.Message):
    r"""Metadata of an ImportData operation.
    Attributes:
        dataset (str):
            Output only. The name of imported dataset.
            "projects/*/datasets/*".
        partial_failures (Sequence[google.rpc.status_pb2.Status]):
            Output only. Partial failures encountered.
            E.g. single files that couldn't be read.
            Status details field will contain standard GCP
            error details.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when import dataset
            request was created.
    """

    dataset = proto.Field(proto.STRING, number=1,)
    partial_failures = proto.RepeatedField(
        proto.MESSAGE, number=2, message=status_pb2.Status,
    )
    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)


class ExportDataOperationMetadata(proto.Message):
    r"""Metadata of an ExportData operation.
    Attributes:
        dataset (str):
            Output only. The name of dataset to be exported.
            "projects/*/datasets/*".
        partial_failures (Sequence[google.rpc.status_pb2.Status]):
            Output only. Partial failures encountered.
            E.g. single files that couldn't be read.
            Status details field will contain standard GCP
            error details.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when export dataset
            request was created.
    """

    dataset = proto.Field(proto.STRING, number=1,)
    partial_failures = proto.RepeatedField(
        proto.MESSAGE, number=2, message=status_pb2.Status,
    )
    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)


class LabelOperationMetadata(proto.Message):
    r"""Metadata of a labeling operation, such as LabelImage or
    LabelVideo. Next tag: 20

    Attributes:
        image_classification_details (google.cloud.datalabeling_v1beta1.types.LabelImageClassificationOperationMetadata):
            Details of label image classification
            operation.
        image_bounding_box_details (google.cloud.datalabeling_v1beta1.types.LabelImageBoundingBoxOperationMetadata):
            Details of label image bounding box
            operation.
        image_bounding_poly_details (google.cloud.datalabeling_v1beta1.types.LabelImageBoundingPolyOperationMetadata):
            Details of label image bounding poly
            operation.
        image_oriented_bounding_box_details (google.cloud.datalabeling_v1beta1.types.LabelImageOrientedBoundingBoxOperationMetadata):
            Details of label image oriented bounding box
            operation.
        image_polyline_details (google.cloud.datalabeling_v1beta1.types.LabelImagePolylineOperationMetadata):
            Details of label image polyline operation.
        image_segmentation_details (google.cloud.datalabeling_v1beta1.types.LabelImageSegmentationOperationMetadata):
            Details of label image segmentation
            operation.
        video_classification_details (google.cloud.datalabeling_v1beta1.types.LabelVideoClassificationOperationMetadata):
            Details of label video classification
            operation.
        video_object_detection_details (google.cloud.datalabeling_v1beta1.types.LabelVideoObjectDetectionOperationMetadata):
            Details of label video object detection
            operation.
        video_object_tracking_details (google.cloud.datalabeling_v1beta1.types.LabelVideoObjectTrackingOperationMetadata):
            Details of label video object tracking
            operation.
        video_event_details (google.cloud.datalabeling_v1beta1.types.LabelVideoEventOperationMetadata):
            Details of label video event operation.
        text_classification_details (google.cloud.datalabeling_v1beta1.types.LabelTextClassificationOperationMetadata):
            Details of label text classification
            operation.
        text_entity_extraction_details (google.cloud.datalabeling_v1beta1.types.LabelTextEntityExtractionOperationMetadata):
            Details of label text entity extraction
            operation.
        progress_percent (int):
            Output only. Progress of label operation. Range: [0, 100].
        partial_failures (Sequence[google.rpc.status_pb2.Status]):
            Output only. Partial failures encountered.
            E.g. single files that couldn't be read.
            Status details field will contain standard GCP
            error details.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when labeling request
            was created.
    """

    image_classification_details = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="details",
        message="LabelImageClassificationOperationMetadata",
    )
    image_bounding_box_details = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="details",
        message="LabelImageBoundingBoxOperationMetadata",
    )
    image_bounding_poly_details = proto.Field(
        proto.MESSAGE,
        number=11,
        oneof="details",
        message="LabelImageBoundingPolyOperationMetadata",
    )
    image_oriented_bounding_box_details = proto.Field(
        proto.MESSAGE,
        number=14,
        oneof="details",
        message="LabelImageOrientedBoundingBoxOperationMetadata",
    )
    image_polyline_details = proto.Field(
        proto.MESSAGE,
        number=12,
        oneof="details",
        message="LabelImagePolylineOperationMetadata",
    )
    image_segmentation_details = proto.Field(
        proto.MESSAGE,
        number=15,
        oneof="details",
        message="LabelImageSegmentationOperationMetadata",
    )
    video_classification_details = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="details",
        message="LabelVideoClassificationOperationMetadata",
    )
    video_object_detection_details = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="details",
        message="LabelVideoObjectDetectionOperationMetadata",
    )
    video_object_tracking_details = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="details",
        message="LabelVideoObjectTrackingOperationMetadata",
    )
    video_event_details = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="details",
        message="LabelVideoEventOperationMetadata",
    )
    text_classification_details = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="details",
        message="LabelTextClassificationOperationMetadata",
    )
    text_entity_extraction_details = proto.Field(
        proto.MESSAGE,
        number=13,
        oneof="details",
        message="LabelTextEntityExtractionOperationMetadata",
    )
    progress_percent = proto.Field(proto.INT32, number=1,)
    partial_failures = proto.RepeatedField(
        proto.MESSAGE, number=2, message=status_pb2.Status,
    )
    create_time = proto.Field(
        proto.MESSAGE, number=16, message=timestamp_pb2.Timestamp,
    )


class LabelImageClassificationOperationMetadata(proto.Message):
    r"""Metadata of a LabelImageClassification operation.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelImageBoundingBoxOperationMetadata(proto.Message):
    r"""Details of a LabelImageBoundingBox operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelImageOrientedBoundingBoxOperationMetadata(proto.Message):
    r"""Details of a LabelImageOrientedBoundingBox operation
    metadata.

    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelImageBoundingPolyOperationMetadata(proto.Message):
    r"""Details of LabelImageBoundingPoly operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelImagePolylineOperationMetadata(proto.Message):
    r"""Details of LabelImagePolyline operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelImageSegmentationOperationMetadata(proto.Message):
    r"""Details of a LabelImageSegmentation operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelVideoClassificationOperationMetadata(proto.Message):
    r"""Details of a LabelVideoClassification operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelVideoObjectDetectionOperationMetadata(proto.Message):
    r"""Details of a LabelVideoObjectDetection operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelVideoObjectTrackingOperationMetadata(proto.Message):
    r"""Details of a LabelVideoObjectTracking operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelVideoEventOperationMetadata(proto.Message):
    r"""Details of a LabelVideoEvent operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelTextClassificationOperationMetadata(proto.Message):
    r"""Details of a LabelTextClassification operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class LabelTextEntityExtractionOperationMetadata(proto.Message):
    r"""Details of a LabelTextEntityExtraction operation metadata.
    Attributes:
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Basic human annotation config used in
            labeling request.
    """

    basic_config = proto.Field(
        proto.MESSAGE, number=1, message=human_annotation_config.HumanAnnotationConfig,
    )


class CreateInstructionMetadata(proto.Message):
    r"""Metadata of a CreateInstruction operation.
    Attributes:
        instruction (str):
            The name of the created Instruction.
            projects/{project_id}/instructions/{instruction_id}
        partial_failures (Sequence[google.rpc.status_pb2.Status]):
            Partial failures encountered.
            E.g. single files that couldn't be read.
            Status details field will contain standard GCP
            error details.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Timestamp when create instruction request was
            created.
    """

    instruction = proto.Field(proto.STRING, number=1,)
    partial_failures = proto.RepeatedField(
        proto.MESSAGE, number=2, message=status_pb2.Status,
    )
    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.datalabeling_v1beta1.types import dataset
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={"Instruction", "CsvInstruction", "PdfInstruction",},
)


class Instruction(proto.Message):
    r"""Instruction of how to perform the labeling task for human
    operators. Currently only PDF instruction is supported.

    Attributes:
        name (str):
            Output only. Instruction resource name, format:
            projects/{project_id}/instructions/{instruction_id}
        display_name (str):
            Required. The display name of the
            instruction. Maximum of 64 characters.
        description (str):
            Optional. User-provided description of the
            instruction. The description can be up to 10000
            characters long.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Creation time of instruction.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Last update time of instruction.
        data_type (google.cloud.datalabeling_v1beta1.types.DataType):
            Required. The data type of this instruction.
        csv_instruction (google.cloud.datalabeling_v1beta1.types.CsvInstruction):
            Deprecated: this instruction format is not supported any
            more. Instruction from a CSV file, such as for
            classification task. The CSV file should have exact two
            columns, in the following format:

            -  The first column is labeled data, such as an image
               reference, text.
            -  The second column is comma separated labels associated
               with data.
        pdf_instruction (google.cloud.datalabeling_v1beta1.types.PdfInstruction):
            Instruction from a PDF document. The PDF
            should be in a Cloud Storage bucket.
        blocking_resources (Sequence[str]):
            Output only. The names of any related
            resources that are blocking changes to the
            instruction.
    """

    name = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)
    description = proto.Field(proto.STRING, number=3,)
    create_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
    update_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
    data_type = proto.Field(proto.ENUM, number=6, enum=dataset.DataType,)
    csv_instruction = proto.Field(proto.MESSAGE, number=7, message="CsvInstruction",)
    pdf_instruction = proto.Field(proto.MESSAGE, number=9, message="PdfInstruction",)
    blocking_resources = proto.RepeatedField(proto.STRING, number=10,)


class CsvInstruction(proto.Message):
    r"""Deprecated: this instruction format is not supported any
    more. Instruction from a CSV file.

    Attributes:
        gcs_file_uri (str):
            CSV file for the instruction. Only gcs path
            is allowed.
    """

    gcs_file_uri = proto.Field(proto.STRING, number=1,)


class PdfInstruction(proto.Message):
    r"""Instruction from a PDF file.
    Attributes:
        gcs_file_uri (str):
            PDF file for the instruction. Only gcs path
            is allowed.
    """

    gcs_file_uri = proto.Field(proto.STRING, number=1,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.protobuf import duration_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={
        "StringAggregationType",
        "HumanAnnotationConfig",
        "ImageClassificationConfig",
        "BoundingPolyConfig",
        "PolylineConfig",
        "SegmentationConfig",
        "VideoClassificationConfig",
        "ObjectDetectionConfig",
        "ObjectTrackingConfig",
        "EventConfig",
        "TextClassificationConfig",
        "SentimentConfig",
        "TextEntityExtractionConfig",
    },
)


class StringAggregationType(proto.Enum):
    r""""""
    STRING_AGGREGATION_TYPE_UNSPECIFIED = 0
    MAJORITY_VOTE = 1
    UNANIMOUS_VOTE = 2
    NO_AGGREGATION = 3


class HumanAnnotationConfig(proto.Message):
    r"""Configuration for how human labeling task should be done.
    Attributes:
        instruction (str):
            Required. Instruction resource name.
        annotated_dataset_display_name (str):
            Required. A human-readable name for
            AnnotatedDataset defined by users. Maximum of 64
            characters .
        annotated_dataset_description (str):
            Optional. A human-readable description for
            AnnotatedDataset. The description can be up to
            10000 characters long.
        label_group (str):
            Optional. A human-readable label used to logically group
            labeling tasks. This string must match the regular
            expression ``[a-zA-Z\\d_-]{0,128}``.
        language_code (str):
            Optional. The Language of this question, as a
            `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__.
            Default value is en-US. Only need to set this when task is
            language related. For example, French text classification.
        replica_count (int):
            Optional. Replication of questions. Each
            question will be sent to up to this number of
            contributors to label. Aggregated answers will
            be returned. Default is set to 1.
            For image related labeling, valid values are 1,
            3, 5.
        question_duration (google.protobuf.duration_pb2.Duration):
            Optional. Maximum duration for contributors
            to answer a question. Maximum is 3600 seconds.
            Default is 3600 seconds.
        contributor_emails (Sequence[str]):
            Optional. If you want your own labeling
            contributors to manage and work on this labeling
            request, you can set these contributors here. We
            will give them access to the question types in
            crowdcompute. Note that these emails must be
            registered in crowdcompute worker UI:
            https://crowd-compute.appspot.com/
        user_email_address (str):
            Email of the user who started the labeling
            task and should be notified by email. If empty
            no notification will be sent.
    """

    instruction = proto.Field(proto.STRING, number=1,)
    annotated_dataset_display_name = proto.Field(proto.STRING, number=2,)
    annotated_dataset_description = proto.Field(proto.STRING, number=3,)
    label_group = proto.Field(proto.STRING, number=4,)
    language_code = proto.Field(proto.STRING, number=5,)
    replica_count = proto.Field(proto.INT32, number=6,)
    question_duration = proto.Field(
        proto.MESSAGE, number=7, message=duration_pb2.Duration,
    )
    contributor_emails = proto.RepeatedField(proto.STRING, number=9,)
    user_email_address = proto.Field(proto.STRING, number=10,)


class ImageClassificationConfig(proto.Message):
    r"""Config for image classification human labeling task.
    Attributes:
        annotation_spec_set (str):
            Required. Annotation spec set resource name.
        allow_multi_label (bool):
            Optional. If allow_multi_label is true, contributors are
            able to choose multiple labels for one image.
        answer_aggregation_type (google.cloud.datalabeling_v1beta1.types.StringAggregationType):
            Optional. The type of how to aggregate
            answers.
    """

    annotation_spec_set = proto.Field(proto.STRING, number=1,)
    allow_multi_label = proto.Field(proto.BOOL, number=2,)
    answer_aggregation_type = proto.Field(
        proto.ENUM, number=3, enum="StringAggregationType",
    )


class BoundingPolyConfig(proto.Message):
    r"""Config for image bounding poly (and bounding box) human
    labeling task.

    Attributes:
        annotation_spec_set (str):
            Required. Annotation spec set resource name.
        instruction_message (str):
            Optional. Instruction message showed on
            contributors UI.
    """

    annotation_spec_set = proto.Field(proto.STRING, number=1,)
    instruction_message = proto.Field(proto.STRING, number=2,)


class PolylineConfig(proto.Message):
    r"""Config for image polyline human labeling task.
    Attributes:
        annotation_spec_set (str):
            Required. Annotation spec set resource name.
        instruction_message (str):
            Optional. Instruction message showed on
            contributors UI.
    """

    annotation_spec_set = proto.Field(proto.STRING, number=1,)
    instruction_message = proto.Field(proto.STRING, number=2,)


class SegmentationConfig(proto.Message):
    r"""Config for image segmentation
    Attributes:
        annotation_spec_set (str):
            Required. Annotation spec set resource name. format:
            projects/{project_id}/annotationSpecSets/{annotation_spec_set_id}
        instruction_message (str):
            Instruction message showed on labelers UI.
    """

    annotation_spec_set = proto.Field(proto.STRING, number=1,)
    instruction_message = proto.Field(proto.STRING, number=2,)


class VideoClassificationConfig(proto.Message):
    r"""Config for video classification human labeling task.
    Currently two types of video classification are supported: 1.
    Assign labels on the entire video.
    2. Split the video into multiple video clips based on camera
    shot, and assign labels on each video clip.

    Attributes:
        annotation_spec_set_configs (Sequence[google.cloud.datalabeling_v1beta1.types.VideoClassificationConfig.AnnotationSpecSetConfig]):
            Required. The list of annotation spec set
            configs. Since watching a video clip takes much
            longer time than an image, we support label with
            multiple AnnotationSpecSet at the same time.
            Labels in each AnnotationSpecSet will be shown
            in a group to contributors. Contributors can
            select one or more (depending on whether to
            allow multi label) from each group.
        apply_shot_detection (bool):
            Optional. Option to apply shot detection on
            the video.
    """

    class AnnotationSpecSetConfig(proto.Message):
        r"""Annotation spec set with the setting of allowing multi labels
        or not.

        Attributes:
            annotation_spec_set (str):
                Required. Annotation spec set resource name.
            allow_multi_label (bool):
                Optional. If allow_multi_label is true, contributors are
                able to choose multiple labels from one annotation spec set.
        """

        annotation_spec_set = proto.Field(proto.STRING, number=1,)
        allow_multi_label = proto.Field(proto.BOOL, number=2,)

    annotation_spec_set_configs = proto.RepeatedField(
        proto.MESSAGE, number=1, message=AnnotationSpecSetConfig,
    )
    apply_shot_detection = proto.Field(proto.BOOL, number=2,)


class ObjectDetectionConfig(proto.Message):
    r"""Config for video object detection human labeling task.
    Object detection will be conducted on the images extracted from
    the video, and those objects will be labeled with bounding
    boxes. User need to specify the number of images to be extracted
    per second as the extraction frame rate.

    Attributes:
        annotation_spec_set (str):
            Required. Annotation spec set resource name.
        extraction_frame_rate (float):
            Required. Number of frames per second to be
            extracted from the video.
    """

    annotation_spec_set = proto.Field(proto.STRING, number=1,)
    extraction_frame_rate = proto.Field(proto.DOUBLE, number=3,)


class ObjectTrackingConfig(proto.Message):
    r"""Config for video object tracking human labeling task.
    Attributes:
        annotation_spec_set (str):
            Required. Annotation spec set resource name.
    """

    annotation_spec_set = proto.Field(proto.STRING, number=1,)


class EventConfig(proto.Message):
    r"""Config for video event human labeling task.
    Attributes:
        annotation_spec_sets (Sequence[str]):
            Required. The list of annotation spec set
            resource name. Similar to video classification,
            we support selecting event from multiple
            AnnotationSpecSet at the same time.
    """

    annotation_spec_sets = proto.RepeatedField(proto.STRING, number=1,)


class TextClassificationConfig(proto.Message):
    r"""Config for text classification human labeling task.
    Attributes:
        allow_multi_label (bool):
            Optional. If allow_multi_label is true, contributors are
            able to choose multiple labels for one text segment.
        annotation_spec_set (str):
            Required. Annotation spec set resource name.
        sentiment_config (google.cloud.datalabeling_v1beta1.types.SentimentConfig):
            Optional. Configs for sentiment selection.
    """

    allow_multi_label = proto.Field(proto.BOOL, number=1,)
    annotation_spec_set = proto.Field(proto.STRING, number=2,)
    sentiment_config = proto.Field(proto.MESSAGE, number=3, message="SentimentConfig",)


class SentimentConfig(proto.Message):
    r"""Config for setting up sentiments.
    Attributes:
        enable_label_sentiment_selection (bool):
            If set to true, contributors will have the
            option to select sentiment of the label they
            selected, to mark it as negative or positive
            label. Default is false.
    """

    enable_label_sentiment_selection = proto.Field(proto.BOOL, number=1,)


class TextEntityExtractionConfig(proto.Message):
    r"""Config for text entity extraction human labeling task.
    Attributes:
        annotation_spec_set (str):
            Required. Annotation spec set resource name.
    """

    annotation_spec_set = proto.Field(proto.STRING, number=1,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.datalabeling_v1beta1.types import annotation
from google.cloud.datalabeling_v1beta1.types import annotation_spec_set
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={
        "Evaluation",
        "EvaluationConfig",
        "BoundingBoxEvaluationOptions",
        "EvaluationMetrics",
        "ClassificationMetrics",
        "ObjectDetectionMetrics",
        "PrCurve",
        "ConfusionMatrix",
    },
)


class Evaluation(proto.Message):
    r"""Describes an evaluation between a machine learning model's
    predictions and ground truth labels. Created when an
    [EvaluationJob][google.cloud.datalabeling.v1beta1.EvaluationJob]
    runs successfully.

    Attributes:
        name (str):
            Output only. Resource name of an evaluation. The name has
            the following format:

            "projects/{project_id}/datasets/{dataset_id}/evaluations/{evaluation_id}'
        config (google.cloud.datalabeling_v1beta1.types.EvaluationConfig):
            Output only. Options used in the evaluation
            job that created this evaluation.
        evaluation_job_run_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp for when the
            evaluation job that created this evaluation ran.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp for when this
            evaluation was created.
        evaluation_metrics (google.cloud.datalabeling_v1beta1.types.EvaluationMetrics):
            Output only. Metrics comparing predictions to
            ground truth labels.
        annotation_type (google.cloud.datalabeling_v1beta1.types.AnnotationType):
            Output only. Type of task that the model version being
            evaluated performs, as defined in the

            [evaluationJobConfig.inputConfig.annotationType][google.cloud.datalabeling.v1beta1.EvaluationJobConfig.input_config]
            field of the evaluation job that created this evaluation.
        evaluated_item_count (int):
            Output only. The number of items in the
            ground truth dataset that were used for this
            evaluation. Only populated when the evaulation
            is for certain AnnotationTypes.
    """

    name = proto.Field(proto.STRING, number=1,)
    config = proto.Field(proto.MESSAGE, number=2, message="EvaluationConfig",)
    evaluation_job_run_time = proto.Field(
        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
    )
    create_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
    evaluation_metrics = proto.Field(
        proto.MESSAGE, number=5, message="EvaluationMetrics",
    )
    annotation_type = proto.Field(proto.ENUM, number=6, enum=annotation.AnnotationType,)
    evaluated_item_count = proto.Field(proto.INT64, number=7,)


class EvaluationConfig(proto.Message):
    r"""Configuration details used for calculating evaluation metrics and
    creating an
    [Evaluation][google.cloud.datalabeling.v1beta1.Evaluation].

    Attributes:
        bounding_box_evaluation_options (google.cloud.datalabeling_v1beta1.types.BoundingBoxEvaluationOptions):
            Only specify this field if the related model performs image
            object detection (``IMAGE_BOUNDING_BOX_ANNOTATION``).
            Describes how to evaluate bounding boxes.
    """

    bounding_box_evaluation_options = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="vertical_option",
        message="BoundingBoxEvaluationOptions",
    )


class BoundingBoxEvaluationOptions(proto.Message):
    r"""Options regarding evaluation between bounding boxes.
    Attributes:
        iou_threshold (float):
            Minimum [intersection-over-union

            (IOU)](/vision/automl/object-detection/docs/evaluate#intersection-over-union)
            required for 2 bounding boxes to be considered a match. This
            must be a number between 0 and 1.
    """

    iou_threshold = proto.Field(proto.FLOAT, number=1,)


class EvaluationMetrics(proto.Message):
    r"""
    Attributes:
        classification_metrics (google.cloud.datalabeling_v1beta1.types.ClassificationMetrics):

        object_detection_metrics (google.cloud.datalabeling_v1beta1.types.ObjectDetectionMetrics):

    """

    classification_metrics = proto.Field(
        proto.MESSAGE, number=1, oneof="metrics", message="ClassificationMetrics",
    )
    object_detection_metrics = proto.Field(
        proto.MESSAGE, number=2, oneof="metrics", message="ObjectDetectionMetrics",
    )


class ClassificationMetrics(proto.Message):
    r"""Metrics calculated for a classification model.
    Attributes:
        pr_curve (google.cloud.datalabeling_v1beta1.types.PrCurve):
            Precision-recall curve based on ground truth
            labels, predicted labels, and scores for the
            predicted labels.
        confusion_matrix (google.cloud.datalabeling_v1beta1.types.ConfusionMatrix):
            Confusion matrix of predicted labels vs.
            ground truth labels.
    """

    pr_curve = proto.Field(proto.MESSAGE, number=1, message="PrCurve",)
    confusion_matrix = proto.Field(proto.MESSAGE, number=2, message="ConfusionMatrix",)


class ObjectDetectionMetrics(proto.Message):
    r"""Metrics calculated for an image object detection (bounding
    box) model.

    Attributes:
        pr_curve (google.cloud.datalabeling_v1beta1.types.PrCurve):
            Precision-recall curve.
    """

    pr_curve = proto.Field(proto.MESSAGE, number=1, message="PrCurve",)


class PrCurve(proto.Message):
    r"""
    Attributes:
        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            The annotation spec of the label for which
            the precision-recall curve calculated. If this
            field is empty, that means the precision-recall
            curve is an aggregate curve for all labels.
        area_under_curve (float):
            Area under the precision-recall curve. Not to
            be confused with area under a receiver operating
            characteristic (ROC) curve.
        confidence_metrics_entries (Sequence[google.cloud.datalabeling_v1beta1.types.PrCurve.ConfidenceMetricsEntry]):
            Entries that make up the precision-recall graph. Each entry
            is a "point" on the graph drawn for a different
            ``confidence_threshold``.
        mean_average_precision (float):
            Mean average prcision of this curve.
    """

    class ConfidenceMetricsEntry(proto.Message):
        r"""
        Attributes:
            confidence_threshold (float):
                Threshold used for this entry.

                For classification tasks, this is a classification
                threshold: a predicted label is categorized as positive or
                negative (in the context of this point on the PR curve)
                based on whether the label's score meets this threshold.

                For image object detection (bounding box) tasks, this is the
                [intersection-over-union

                (IOU)](/vision/automl/object-detection/docs/evaluate#intersection-over-union)
                threshold for the context of this point on the PR curve.
            recall (float):
                Recall value.
            precision (float):
                Precision value.
            f1_score (float):
                Harmonic mean of recall and precision.
            recall_at1 (float):
                Recall value for entries with label that has
                highest score.
            precision_at1 (float):
                Precision value for entries with label that
                has highest score.
            f1_score_at1 (float):
                The harmonic mean of
                [recall_at1][google.cloud.datalabeling.v1beta1.PrCurve.ConfidenceMetricsEntry.recall_at1]
                and
                [precision_at1][google.cloud.datalabeling.v1beta1.PrCurve.ConfidenceMetricsEntry.precision_at1].
            recall_at5 (float):
                Recall value for entries with label that has
                highest 5 scores.
            precision_at5 (float):
                Precision value for entries with label that
                has highest 5 scores.
            f1_score_at5 (float):
                The harmonic mean of
                [recall_at5][google.cloud.datalabeling.v1beta1.PrCurve.ConfidenceMetricsEntry.recall_at5]
                and
                [precision_at5][google.cloud.datalabeling.v1beta1.PrCurve.ConfidenceMetricsEntry.precision_at5].
        """

        confidence_threshold = proto.Field(proto.FLOAT, number=1,)
        recall = proto.Field(proto.FLOAT, number=2,)
        precision = proto.Field(proto.FLOAT, number=3,)
        f1_score = proto.Field(proto.FLOAT, number=4,)
        recall_at1 = proto.Field(proto.FLOAT, number=5,)
        precision_at1 = proto.Field(proto.FLOAT, number=6,)
        f1_score_at1 = proto.Field(proto.FLOAT, number=7,)
        recall_at5 = proto.Field(proto.FLOAT, number=8,)
        precision_at5 = proto.Field(proto.FLOAT, number=9,)
        f1_score_at5 = proto.Field(proto.FLOAT, number=10,)

    annotation_spec = proto.Field(
        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
    )
    area_under_curve = proto.Field(proto.FLOAT, number=2,)
    confidence_metrics_entries = proto.RepeatedField(
        proto.MESSAGE, number=3, message=ConfidenceMetricsEntry,
    )
    mean_average_precision = proto.Field(proto.FLOAT, number=4,)


class ConfusionMatrix(proto.Message):
    r"""Confusion matrix of the model running the classification.
    Only applicable when the metrics entry aggregates multiple
    labels. Not applicable when the entry is for a single label.

    Attributes:
        row (Sequence[google.cloud.datalabeling_v1beta1.types.ConfusionMatrix.Row]):

    """

    class ConfusionMatrixEntry(proto.Message):
        r"""
        Attributes:
            annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
                The annotation spec of a predicted label.
            item_count (int):
                Number of items predicted to have this label. (The ground
                truth label for these items is the ``Row.annotationSpec`` of
                this entry's parent.)
        """

        annotation_spec = proto.Field(
            proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
        )
        item_count = proto.Field(proto.INT32, number=2,)

    class Row(proto.Message):
        r"""A row in the confusion matrix. Each entry in this row has the
        same ground truth label.

        Attributes:
            annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
                The annotation spec of the ground truth label
                for this row.
            entries (Sequence[google.cloud.datalabeling_v1beta1.types.ConfusionMatrix.ConfusionMatrixEntry]):
                A list of the confusion matrix entries. One
                entry for each possible predicted label.
        """

        annotation_spec = proto.Field(
            proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
        )
        entries = proto.RepeatedField(
            proto.MESSAGE, number=2, message="ConfusionMatrix.ConfusionMatrixEntry",
        )

    row = proto.RepeatedField(proto.MESSAGE, number=1, message=Row,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Sequence,
    Tuple,
    Optional,
    Iterator,
)

from google.cloud.datalabeling_v1beta1.types import annotation_spec_set
from google.cloud.datalabeling_v1beta1.types import data_labeling_service
from google.cloud.datalabeling_v1beta1.types import dataset
from google.cloud.datalabeling_v1beta1.types import evaluation
from google.cloud.datalabeling_v1beta1.types import evaluation_job
from google.cloud.datalabeling_v1beta1.types import instruction


class ListDatasetsPager:
    """A pager for iterating through ``list_datasets`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListDatasetsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``datasets`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListDatasets`` requests and continue to iterate
    through the ``datasets`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListDatasetsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.ListDatasetsResponse],
        request: data_labeling_service.ListDatasetsRequest,
        response: data_labeling_service.ListDatasetsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListDatasetsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListDatasetsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListDatasetsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.ListDatasetsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[dataset.Dataset]:
        for page in self.pages:
            yield from page.datasets

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListDatasetsAsyncPager:
    """A pager for iterating through ``list_datasets`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListDatasetsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``datasets`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListDatasets`` requests and continue to iterate
    through the ``datasets`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListDatasetsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[data_labeling_service.ListDatasetsResponse]],
        request: data_labeling_service.ListDatasetsRequest,
        response: data_labeling_service.ListDatasetsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListDatasetsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListDatasetsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListDatasetsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[data_labeling_service.ListDatasetsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[dataset.Dataset]:
        async def async_generator():
            async for page in self.pages:
                for response in page.datasets:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListDataItemsPager:
    """A pager for iterating through ``list_data_items`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListDataItemsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``data_items`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListDataItems`` requests and continue to iterate
    through the ``data_items`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListDataItemsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.ListDataItemsResponse],
        request: data_labeling_service.ListDataItemsRequest,
        response: data_labeling_service.ListDataItemsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListDataItemsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListDataItemsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListDataItemsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.ListDataItemsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[dataset.DataItem]:
        for page in self.pages:
            yield from page.data_items

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListDataItemsAsyncPager:
    """A pager for iterating through ``list_data_items`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListDataItemsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``data_items`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListDataItems`` requests and continue to iterate
    through the ``data_items`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListDataItemsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[data_labeling_service.ListDataItemsResponse]],
        request: data_labeling_service.ListDataItemsRequest,
        response: data_labeling_service.ListDataItemsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListDataItemsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListDataItemsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListDataItemsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[data_labeling_service.ListDataItemsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[dataset.DataItem]:
        async def async_generator():
            async for page in self.pages:
                for response in page.data_items:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListAnnotatedDatasetsPager:
    """A pager for iterating through ``list_annotated_datasets`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListAnnotatedDatasetsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``annotated_datasets`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListAnnotatedDatasets`` requests and continue to iterate
    through the ``annotated_datasets`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListAnnotatedDatasetsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.ListAnnotatedDatasetsResponse],
        request: data_labeling_service.ListAnnotatedDatasetsRequest,
        response: data_labeling_service.ListAnnotatedDatasetsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListAnnotatedDatasetsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListAnnotatedDatasetsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListAnnotatedDatasetsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.ListAnnotatedDatasetsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[dataset.AnnotatedDataset]:
        for page in self.pages:
            yield from page.annotated_datasets

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListAnnotatedDatasetsAsyncPager:
    """A pager for iterating through ``list_annotated_datasets`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListAnnotatedDatasetsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``annotated_datasets`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListAnnotatedDatasets`` requests and continue to iterate
    through the ``annotated_datasets`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListAnnotatedDatasetsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[data_labeling_service.ListAnnotatedDatasetsResponse]
        ],
        request: data_labeling_service.ListAnnotatedDatasetsRequest,
        response: data_labeling_service.ListAnnotatedDatasetsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListAnnotatedDatasetsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListAnnotatedDatasetsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListAnnotatedDatasetsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterator[data_labeling_service.ListAnnotatedDatasetsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[dataset.AnnotatedDataset]:
        async def async_generator():
            async for page in self.pages:
                for response in page.annotated_datasets:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListExamplesPager:
    """A pager for iterating through ``list_examples`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListExamplesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``examples`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListExamples`` requests and continue to iterate
    through the ``examples`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListExamplesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.ListExamplesResponse],
        request: data_labeling_service.ListExamplesRequest,
        response: data_labeling_service.ListExamplesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListExamplesRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListExamplesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListExamplesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.ListExamplesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[dataset.Example]:
        for page in self.pages:
            yield from page.examples

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListExamplesAsyncPager:
    """A pager for iterating through ``list_examples`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListExamplesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``examples`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListExamples`` requests and continue to iterate
    through the ``examples`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListExamplesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[data_labeling_service.ListExamplesResponse]],
        request: data_labeling_service.ListExamplesRequest,
        response: data_labeling_service.ListExamplesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListExamplesRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListExamplesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListExamplesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[data_labeling_service.ListExamplesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[dataset.Example]:
        async def async_generator():
            async for page in self.pages:
                for response in page.examples:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListAnnotationSpecSetsPager:
    """A pager for iterating through ``list_annotation_spec_sets`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListAnnotationSpecSetsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``annotation_spec_sets`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListAnnotationSpecSets`` requests and continue to iterate
    through the ``annotation_spec_sets`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListAnnotationSpecSetsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.ListAnnotationSpecSetsResponse],
        request: data_labeling_service.ListAnnotationSpecSetsRequest,
        response: data_labeling_service.ListAnnotationSpecSetsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListAnnotationSpecSetsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListAnnotationSpecSetsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListAnnotationSpecSetsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.ListAnnotationSpecSetsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[annotation_spec_set.AnnotationSpecSet]:
        for page in self.pages:
            yield from page.annotation_spec_sets

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListAnnotationSpecSetsAsyncPager:
    """A pager for iterating through ``list_annotation_spec_sets`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListAnnotationSpecSetsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``annotation_spec_sets`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListAnnotationSpecSets`` requests and continue to iterate
    through the ``annotation_spec_sets`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListAnnotationSpecSetsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[data_labeling_service.ListAnnotationSpecSetsResponse]
        ],
        request: data_labeling_service.ListAnnotationSpecSetsRequest,
        response: data_labeling_service.ListAnnotationSpecSetsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListAnnotationSpecSetsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListAnnotationSpecSetsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListAnnotationSpecSetsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterator[data_labeling_service.ListAnnotationSpecSetsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[annotation_spec_set.AnnotationSpecSet]:
        async def async_generator():
            async for page in self.pages:
                for response in page.annotation_spec_sets:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListInstructionsPager:
    """A pager for iterating through ``list_instructions`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListInstructionsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``instructions`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListInstructions`` requests and continue to iterate
    through the ``instructions`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListInstructionsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.ListInstructionsResponse],
        request: data_labeling_service.ListInstructionsRequest,
        response: data_labeling_service.ListInstructionsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListInstructionsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListInstructionsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListInstructionsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.ListInstructionsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[instruction.Instruction]:
        for page in self.pages:
            yield from page.instructions

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListInstructionsAsyncPager:
    """A pager for iterating through ``list_instructions`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListInstructionsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``instructions`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListInstructions`` requests and continue to iterate
    through the ``instructions`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListInstructionsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[data_labeling_service.ListInstructionsResponse]
        ],
        request: data_labeling_service.ListInstructionsRequest,
        response: data_labeling_service.ListInstructionsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListInstructionsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListInstructionsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListInstructionsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterator[data_labeling_service.ListInstructionsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[instruction.Instruction]:
        async def async_generator():
            async for page in self.pages:
                for response in page.instructions:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class SearchEvaluationsPager:
    """A pager for iterating through ``search_evaluations`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.SearchEvaluationsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``evaluations`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``SearchEvaluations`` requests and continue to iterate
    through the ``evaluations`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.SearchEvaluationsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.SearchEvaluationsResponse],
        request: data_labeling_service.SearchEvaluationsRequest,
        response: data_labeling_service.SearchEvaluationsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.SearchEvaluationsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.SearchEvaluationsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.SearchEvaluationsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.SearchEvaluationsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[evaluation.Evaluation]:
        for page in self.pages:
            yield from page.evaluations

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class SearchEvaluationsAsyncPager:
    """A pager for iterating through ``search_evaluations`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.SearchEvaluationsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``evaluations`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``SearchEvaluations`` requests and continue to iterate
    through the ``evaluations`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.SearchEvaluationsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[data_labeling_service.SearchEvaluationsResponse]
        ],
        request: data_labeling_service.SearchEvaluationsRequest,
        response: data_labeling_service.SearchEvaluationsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.SearchEvaluationsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.SearchEvaluationsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.SearchEvaluationsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterator[data_labeling_service.SearchEvaluationsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[evaluation.Evaluation]:
        async def async_generator():
            async for page in self.pages:
                for response in page.evaluations:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class SearchExampleComparisonsPager:
    """A pager for iterating through ``search_example_comparisons`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``example_comparisons`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``SearchExampleComparisons`` requests and continue to iterate
    through the ``example_comparisons`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.SearchExampleComparisonsResponse],
        request: data_labeling_service.SearchExampleComparisonsRequest,
        response: data_labeling_service.SearchExampleComparisonsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.SearchExampleComparisonsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.SearchExampleComparisonsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(
        self,
    ) -> Iterator[
        data_labeling_service.SearchExampleComparisonsResponse.ExampleComparison
    ]:
        for page in self.pages:
            yield from page.example_comparisons

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class SearchExampleComparisonsAsyncPager:
    """A pager for iterating through ``search_example_comparisons`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``example_comparisons`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``SearchExampleComparisons`` requests and continue to iterate
    through the ``example_comparisons`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[data_labeling_service.SearchExampleComparisonsResponse]
        ],
        request: data_labeling_service.SearchExampleComparisonsRequest,
        response: data_labeling_service.SearchExampleComparisonsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.SearchExampleComparisonsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterator[data_labeling_service.SearchExampleComparisonsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(
        self,
    ) -> AsyncIterator[
        data_labeling_service.SearchExampleComparisonsResponse.ExampleComparison
    ]:
        async def async_generator():
            async for page in self.pages:
                for response in page.example_comparisons:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListEvaluationJobsPager:
    """A pager for iterating through ``list_evaluation_jobs`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListEvaluationJobsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``evaluation_jobs`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListEvaluationJobs`` requests and continue to iterate
    through the ``evaluation_jobs`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListEvaluationJobsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., data_labeling_service.ListEvaluationJobsResponse],
        request: data_labeling_service.ListEvaluationJobsRequest,
        response: data_labeling_service.ListEvaluationJobsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListEvaluationJobsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListEvaluationJobsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListEvaluationJobsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[data_labeling_service.ListEvaluationJobsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[evaluation_job.EvaluationJob]:
        for page in self.pages:
            yield from page.evaluation_jobs

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListEvaluationJobsAsyncPager:
    """A pager for iterating through ``list_evaluation_jobs`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.datalabeling_v1beta1.types.ListEvaluationJobsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``evaluation_jobs`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListEvaluationJobs`` requests and continue to iterate
    through the ``evaluation_jobs`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.datalabeling_v1beta1.types.ListEvaluationJobsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., Awaitable[data_labeling_service.ListEvaluationJobsResponse]
        ],
        request: data_labeling_service.ListEvaluationJobsRequest,
        response: data_labeling_service.ListEvaluationJobsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.datalabeling_v1beta1.types.ListEvaluationJobsRequest):
                The initial request object.
            response (google.cloud.datalabeling_v1beta1.types.ListEvaluationJobsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = data_labeling_service.ListEvaluationJobsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(
        self,
    ) -> AsyncIterator[data_labeling_service.ListEvaluationJobsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[evaluation_job.EvaluationJob]:
        async def async_generator():
            async for page in self.pages:
                for response in page.evaluation_jobs:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.datalabeling_v1beta1.services.data_labeling_service.client import (
    DataLabelingServiceClient,
)
from google.cloud.datalabeling_v1beta1.services.data_labeling_service.async_client import (
    DataLabelingServiceAsyncClient,
)

from google.cloud.datalabeling_v1beta1.types.annotation import Annotation
from google.cloud.datalabeling_v1beta1.types.annotation import AnnotationMetadata
from google.cloud.datalabeling_v1beta1.types.annotation import AnnotationValue
from google.cloud.datalabeling_v1beta1.types.annotation import BoundingPoly
from google.cloud.datalabeling_v1beta1.types.annotation import (
    ImageBoundingPolyAnnotation,
)
from google.cloud.datalabeling_v1beta1.types.annotation import (
    ImageClassificationAnnotation,
)
from google.cloud.datalabeling_v1beta1.types.annotation import ImagePolylineAnnotation
from google.cloud.datalabeling_v1beta1.types.annotation import (
    ImageSegmentationAnnotation,
)
from google.cloud.datalabeling_v1beta1.types.annotation import NormalizedBoundingPoly
from google.cloud.datalabeling_v1beta1.types.annotation import NormalizedPolyline
from google.cloud.datalabeling_v1beta1.types.annotation import NormalizedVertex
from google.cloud.datalabeling_v1beta1.types.annotation import ObjectTrackingFrame
from google.cloud.datalabeling_v1beta1.types.annotation import OperatorMetadata
from google.cloud.datalabeling_v1beta1.types.annotation import Polyline
from google.cloud.datalabeling_v1beta1.types.annotation import SequentialSegment
from google.cloud.datalabeling_v1beta1.types.annotation import (
    TextClassificationAnnotation,
)
from google.cloud.datalabeling_v1beta1.types.annotation import (
    TextEntityExtractionAnnotation,
)
from google.cloud.datalabeling_v1beta1.types.annotation import TimeSegment
from google.cloud.datalabeling_v1beta1.types.annotation import Vertex
from google.cloud.datalabeling_v1beta1.types.annotation import (
    VideoClassificationAnnotation,
)
from google.cloud.datalabeling_v1beta1.types.annotation import VideoEventAnnotation
from google.cloud.datalabeling_v1beta1.types.annotation import (
    VideoObjectTrackingAnnotation,
)
from google.cloud.datalabeling_v1beta1.types.annotation import AnnotationSentiment
from google.cloud.datalabeling_v1beta1.types.annotation import AnnotationSource
from google.cloud.datalabeling_v1beta1.types.annotation import AnnotationType
from google.cloud.datalabeling_v1beta1.types.annotation_spec_set import AnnotationSpec
from google.cloud.datalabeling_v1beta1.types.annotation_spec_set import (
    AnnotationSpecSet,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    CreateAnnotationSpecSetRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    CreateDatasetRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    CreateEvaluationJobRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    CreateInstructionRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    DeleteAnnotatedDatasetRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    DeleteAnnotationSpecSetRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    DeleteDatasetRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    DeleteEvaluationJobRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    DeleteInstructionRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ExportDataRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    GetAnnotatedDatasetRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    GetAnnotationSpecSetRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    GetDataItemRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    GetDatasetRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    GetEvaluationJobRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    GetEvaluationRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    GetExampleRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    GetInstructionRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ImportDataRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    LabelImageRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    LabelTextRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    LabelVideoRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListAnnotatedDatasetsRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListAnnotatedDatasetsResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListAnnotationSpecSetsRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListAnnotationSpecSetsResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListDataItemsRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListDataItemsResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListDatasetsRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListDatasetsResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListEvaluationJobsRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListEvaluationJobsResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListExamplesRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListExamplesResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListInstructionsRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ListInstructionsResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    PauseEvaluationJobRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    ResumeEvaluationJobRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    SearchEvaluationsRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    SearchEvaluationsResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    SearchExampleComparisonsRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    SearchExampleComparisonsResponse,
)
from google.cloud.datalabeling_v1beta1.types.data_labeling_service import (
    UpdateEvaluationJobRequest,
)
from google.cloud.datalabeling_v1beta1.types.data_payloads import ImagePayload
from google.cloud.datalabeling_v1beta1.types.data_payloads import TextPayload
from google.cloud.datalabeling_v1beta1.types.data_payloads import VideoPayload
from google.cloud.datalabeling_v1beta1.types.data_payloads import VideoThumbnail
from google.cloud.datalabeling_v1beta1.types.dataset import AnnotatedDataset
from google.cloud.datalabeling_v1beta1.types.dataset import AnnotatedDatasetMetadata
from google.cloud.datalabeling_v1beta1.types.dataset import BigQuerySource
from google.cloud.datalabeling_v1beta1.types.dataset import ClassificationMetadata
from google.cloud.datalabeling_v1beta1.types.dataset import DataItem
from google.cloud.datalabeling_v1beta1.types.dataset import Dataset
from google.cloud.datalabeling_v1beta1.types.dataset import Example
from google.cloud.datalabeling_v1beta1.types.dataset import GcsDestination
from google.cloud.datalabeling_v1beta1.types.dataset import GcsFolderDestination
from google.cloud.datalabeling_v1beta1.types.dataset import GcsSource
from google.cloud.datalabeling_v1beta1.types.dataset import InputConfig
from google.cloud.datalabeling_v1beta1.types.dataset import LabelStats
from google.cloud.datalabeling_v1beta1.types.dataset import OutputConfig
from google.cloud.datalabeling_v1beta1.types.dataset import TextMetadata
from google.cloud.datalabeling_v1beta1.types.dataset import DataType
from google.cloud.datalabeling_v1beta1.types.evaluation import (
    BoundingBoxEvaluationOptions,
)
from google.cloud.datalabeling_v1beta1.types.evaluation import ClassificationMetrics
from google.cloud.datalabeling_v1beta1.types.evaluation import ConfusionMatrix
from google.cloud.datalabeling_v1beta1.types.evaluation import Evaluation
from google.cloud.datalabeling_v1beta1.types.evaluation import EvaluationConfig
from google.cloud.datalabeling_v1beta1.types.evaluation import EvaluationMetrics
from google.cloud.datalabeling_v1beta1.types.evaluation import ObjectDetectionMetrics
from google.cloud.datalabeling_v1beta1.types.evaluation import PrCurve
from google.cloud.datalabeling_v1beta1.types.evaluation_job import Attempt
from google.cloud.datalabeling_v1beta1.types.evaluation_job import EvaluationJob
from google.cloud.datalabeling_v1beta1.types.evaluation_job import (
    EvaluationJobAlertConfig,
)
from google.cloud.datalabeling_v1beta1.types.evaluation_job import EvaluationJobConfig
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    BoundingPolyConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import EventConfig
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    HumanAnnotationConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    ImageClassificationConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    ObjectDetectionConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    ObjectTrackingConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    PolylineConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    SegmentationConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    SentimentConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    TextClassificationConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    TextEntityExtractionConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    VideoClassificationConfig,
)
from google.cloud.datalabeling_v1beta1.types.human_annotation_config import (
    StringAggregationType,
)
from google.cloud.datalabeling_v1beta1.types.instruction import CsvInstruction
from google.cloud.datalabeling_v1beta1.types.instruction import Instruction
from google.cloud.datalabeling_v1beta1.types.instruction import PdfInstruction
from google.cloud.datalabeling_v1beta1.types.operations import CreateInstructionMetadata
from google.cloud.datalabeling_v1beta1.types.operations import (
    ExportDataOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    ExportDataOperationResponse,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    ImportDataOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    ImportDataOperationResponse,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelImageBoundingBoxOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelImageBoundingPolyOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelImageClassificationOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelImageOrientedBoundingBoxOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelImagePolylineOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelImageSegmentationOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import LabelOperationMetadata
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelTextClassificationOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelTextEntityExtractionOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelVideoClassificationOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelVideoEventOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelVideoObjectDetectionOperationMetadata,
)
from google.cloud.datalabeling_v1beta1.types.operations import (
    LabelVideoObjectTrackingOperationMetadata,
)

__all__ = (
    "DataLabelingServiceClient",
    "DataLabelingServiceAsyncClient",
    "Annotation",
    "AnnotationMetadata",
    "AnnotationValue",
    "BoundingPoly",
    "ImageBoundingPolyAnnotation",
    "ImageClassificationAnnotation",
    "ImagePolylineAnnotation",
    "ImageSegmentationAnnotation",
    "NormalizedBoundingPoly",
    "NormalizedPolyline",
    "NormalizedVertex",
    "ObjectTrackingFrame",
    "OperatorMetadata",
    "Polyline",
    "SequentialSegment",
    "TextClassificationAnnotation",
    "TextEntityExtractionAnnotation",
    "TimeSegment",
    "Vertex",
    "VideoClassificationAnnotation",
    "VideoEventAnnotation",
    "VideoObjectTrackingAnnotation",
    "AnnotationSentiment",
    "AnnotationSource",
    "AnnotationType",
    "AnnotationSpec",
    "AnnotationSpecSet",
    "CreateAnnotationSpecSetRequest",
    "CreateDatasetRequest",
    "CreateEvaluationJobRequest",
    "CreateInstructionRequest",
    "DeleteAnnotatedDatasetRequest",
    "DeleteAnnotationSpecSetRequest",
    "DeleteDatasetRequest",
    "DeleteEvaluationJobRequest",
    "DeleteInstructionRequest",
    "ExportDataRequest",
    "GetAnnotatedDatasetRequest",
    "GetAnnotationSpecSetRequest",
    "GetDataItemRequest",
    "GetDatasetRequest",
    "GetEvaluationJobRequest",
    "GetEvaluationRequest",
    "GetExampleRequest",
    "GetInstructionRequest",
    "ImportDataRequest",
    "LabelImageRequest",
    "LabelTextRequest",
    "LabelVideoRequest",
    "ListAnnotatedDatasetsRequest",
    "ListAnnotatedDatasetsResponse",
    "ListAnnotationSpecSetsRequest",
    "ListAnnotationSpecSetsResponse",
    "ListDataItemsRequest",
    "ListDataItemsResponse",
    "ListDatasetsRequest",
    "ListDatasetsResponse",
    "ListEvaluationJobsRequest",
    "ListEvaluationJobsResponse",
    "ListExamplesRequest",
    "ListExamplesResponse",
    "ListInstructionsRequest",
    "ListInstructionsResponse",
    "PauseEvaluationJobRequest",
    "ResumeEvaluationJobRequest",
    "SearchEvaluationsRequest",
    "SearchEvaluationsResponse",
    "SearchExampleComparisonsRequest",
    "SearchExampleComparisonsResponse",
    "UpdateEvaluationJobRequest",
    "ImagePayload",
    "TextPayload",
    "VideoPayload",
    "VideoThumbnail",
    "AnnotatedDataset",
    "AnnotatedDatasetMetadata",
    "BigQuerySource",
    "ClassificationMetadata",
    "DataItem",
    "Dataset",
    "Example",
    "GcsDestination",
    "GcsFolderDestination",
    "GcsSource",
    "InputConfig",
    "LabelStats",
    "OutputConfig",
    "TextMetadata",
    "DataType",
    "BoundingBoxEvaluationOptions",
    "ClassificationMetrics",
    "ConfusionMatrix",
    "Evaluation",
    "EvaluationConfig",
    "EvaluationMetrics",
    "ObjectDetectionMetrics",
    "PrCurve",
    "Attempt",
    "EvaluationJob",
    "EvaluationJobAlertConfig",
    "EvaluationJobConfig",
    "BoundingPolyConfig",
    "EventConfig",
    "HumanAnnotationConfig",
    "ImageClassificationConfig",
    "ObjectDetectionConfig",
    "ObjectTrackingConfig",
    "PolylineConfig",
    "SegmentationConfig",
    "SentimentConfig",
    "TextClassificationConfig",
    "TextEntityExtractionConfig",
    "VideoClassificationConfig",
    "StringAggregationType",
    "CsvInstruction",
    "Instruction",
    "PdfInstruction",
    "CreateInstructionMetadata",
    "ExportDataOperationMetadata",
    "ExportDataOperationResponse",
    "ImportDataOperationMetadata",
    "ImportDataOperationResponse",
    "LabelImageBoundingBoxOperationMetadata",
    "LabelImageBoundingPolyOperationMetadata",
    "LabelImageClassificationOperationMetadata",
    "LabelImageOrientedBoundingBoxOperationMetadata",
    "LabelImagePolylineOperationMetadata",
    "LabelImageSegmentationOperationMetadata",
    "LabelOperationMetadata",
    "LabelTextClassificationOperationMetadata",
    "LabelTextEntityExtractionOperationMetadata",
    "LabelVideoClassificationOperationMetadata",
    "LabelVideoEventOperationMetadata",
    "LabelVideoObjectDetectionOperationMetadata",
    "LabelVideoObjectTrackingOperationMetadata",
)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.datalabeling_v1beta1.types import annotation_spec_set
from google.protobuf import duration_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={
        "AnnotationSource",
        "AnnotationSentiment",
        "AnnotationType",
        "Annotation",
        "AnnotationValue",
        "ImageClassificationAnnotation",
        "Vertex",
        "NormalizedVertex",
        "BoundingPoly",
        "NormalizedBoundingPoly",
        "ImageBoundingPolyAnnotation",
        "Polyline",
        "NormalizedPolyline",
        "ImagePolylineAnnotation",
        "ImageSegmentationAnnotation",
        "TextClassificationAnnotation",
        "TextEntityExtractionAnnotation",
        "SequentialSegment",
        "TimeSegment",
        "VideoClassificationAnnotation",
        "ObjectTrackingFrame",
        "VideoObjectTrackingAnnotation",
        "VideoEventAnnotation",
        "AnnotationMetadata",
        "OperatorMetadata",
    },
)


class AnnotationSource(proto.Enum):
    r"""Specifies where the annotation comes from (whether it was
    provided by a human labeler or a different source).
    """
    ANNOTATION_SOURCE_UNSPECIFIED = 0
    OPERATOR = 3


class AnnotationSentiment(proto.Enum):
    r""""""
    ANNOTATION_SENTIMENT_UNSPECIFIED = 0
    NEGATIVE = 1
    POSITIVE = 2


class AnnotationType(proto.Enum):
    r""""""
    ANNOTATION_TYPE_UNSPECIFIED = 0
    IMAGE_CLASSIFICATION_ANNOTATION = 1
    IMAGE_BOUNDING_BOX_ANNOTATION = 2
    IMAGE_ORIENTED_BOUNDING_BOX_ANNOTATION = 13
    IMAGE_BOUNDING_POLY_ANNOTATION = 10
    IMAGE_POLYLINE_ANNOTATION = 11
    IMAGE_SEGMENTATION_ANNOTATION = 12
    VIDEO_SHOTS_CLASSIFICATION_ANNOTATION = 3
    VIDEO_OBJECT_TRACKING_ANNOTATION = 4
    VIDEO_OBJECT_DETECTION_ANNOTATION = 5
    VIDEO_EVENT_ANNOTATION = 6
    TEXT_CLASSIFICATION_ANNOTATION = 8
    TEXT_ENTITY_EXTRACTION_ANNOTATION = 9
    GENERAL_CLASSIFICATION_ANNOTATION = 14


class Annotation(proto.Message):
    r"""Annotation for Example. Each example may have one or more
    annotations. For example in image classification problem, each
    image might have one or more labels. We call labels binded with
    this image an Annotation.

    Attributes:
        name (str):
            Output only. Unique name of this annotation, format is:

            projects/{project_id}/datasets/{dataset_id}/annotatedDatasets/{annotated_dataset}/examples/{example_id}/annotations/{annotation_id}
        annotation_source (google.cloud.datalabeling_v1beta1.types.AnnotationSource):
            Output only. The source of the annotation.
        annotation_value (google.cloud.datalabeling_v1beta1.types.AnnotationValue):
            Output only. This is the actual annotation
            value, e.g classification, bounding box values
            are stored here.
        annotation_metadata (google.cloud.datalabeling_v1beta1.types.AnnotationMetadata):
            Output only. Annotation metadata, including
            information like votes for labels.
        annotation_sentiment (google.cloud.datalabeling_v1beta1.types.AnnotationSentiment):
            Output only. Sentiment for this annotation.
    """

    name = proto.Field(proto.STRING, number=1,)
    annotation_source = proto.Field(proto.ENUM, number=2, enum="AnnotationSource",)
    annotation_value = proto.Field(proto.MESSAGE, number=3, message="AnnotationValue",)
    annotation_metadata = proto.Field(
        proto.MESSAGE, number=4, message="AnnotationMetadata",
    )
    annotation_sentiment = proto.Field(
        proto.ENUM, number=6, enum="AnnotationSentiment",
    )


class AnnotationValue(proto.Message):
    r"""Annotation value for an example.
    Attributes:
        image_classification_annotation (google.cloud.datalabeling_v1beta1.types.ImageClassificationAnnotation):
            Annotation value for image classification
            case.
        image_bounding_poly_annotation (google.cloud.datalabeling_v1beta1.types.ImageBoundingPolyAnnotation):
            Annotation value for image bounding box,
            oriented bounding box and polygon cases.
        image_polyline_annotation (google.cloud.datalabeling_v1beta1.types.ImagePolylineAnnotation):
            Annotation value for image polyline cases.
            Polyline here is different from BoundingPoly. It
            is formed by line segments connected to each
            other but not closed form(Bounding Poly). The
            line segments can cross each other.
        image_segmentation_annotation (google.cloud.datalabeling_v1beta1.types.ImageSegmentationAnnotation):
            Annotation value for image segmentation.
        text_classification_annotation (google.cloud.datalabeling_v1beta1.types.TextClassificationAnnotation):
            Annotation value for text classification
            case.
        text_entity_extraction_annotation (google.cloud.datalabeling_v1beta1.types.TextEntityExtractionAnnotation):
            Annotation value for text entity extraction
            case.
        video_classification_annotation (google.cloud.datalabeling_v1beta1.types.VideoClassificationAnnotation):
            Annotation value for video classification
            case.
        video_object_tracking_annotation (google.cloud.datalabeling_v1beta1.types.VideoObjectTrackingAnnotation):
            Annotation value for video object detection
            and tracking case.
        video_event_annotation (google.cloud.datalabeling_v1beta1.types.VideoEventAnnotation):
            Annotation value for video event case.
    """

    image_classification_annotation = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="value_type",
        message="ImageClassificationAnnotation",
    )
    image_bounding_poly_annotation = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="value_type",
        message="ImageBoundingPolyAnnotation",
    )
    image_polyline_annotation = proto.Field(
        proto.MESSAGE, number=8, oneof="value_type", message="ImagePolylineAnnotation",
    )
    image_segmentation_annotation = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="value_type",
        message="ImageSegmentationAnnotation",
    )
    text_classification_annotation = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="value_type",
        message="TextClassificationAnnotation",
    )
    text_entity_extraction_annotation = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof="value_type",
        message="TextEntityExtractionAnnotation",
    )
    video_classification_annotation = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="value_type",
        message="VideoClassificationAnnotation",
    )
    video_object_tracking_annotation = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="value_type",
        message="VideoObjectTrackingAnnotation",
    )
    video_event_annotation = proto.Field(
        proto.MESSAGE, number=6, oneof="value_type", message="VideoEventAnnotation",
    )


class ImageClassificationAnnotation(proto.Message):
    r"""Image classification annotation definition.
    Attributes:
        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            Label of image.
    """

    annotation_spec = proto.Field(
        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
    )


class Vertex(proto.Message):
    r"""A vertex represents a 2D point in the image.
    NOTE: the vertex coordinates are in the same scale as the
    original image.

    Attributes:
        x (int):
            X coordinate.
        y (int):
            Y coordinate.
    """

    x = proto.Field(proto.INT32, number=1,)
    y = proto.Field(proto.INT32, number=2,)


class NormalizedVertex(proto.Message):
    r"""A vertex represents a 2D point in the image.
    NOTE: the normalized vertex coordinates are relative to the
    original image and range from 0 to 1.

    Attributes:
        x (float):
            X coordinate.
        y (float):
            Y coordinate.
    """

    x = proto.Field(proto.FLOAT, number=1,)
    y = proto.Field(proto.FLOAT, number=2,)


class BoundingPoly(proto.Message):
    r"""A bounding polygon in the image.
    Attributes:
        vertices (Sequence[google.cloud.datalabeling_v1beta1.types.Vertex]):
            The bounding polygon vertices.
    """

    vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="Vertex",)


class NormalizedBoundingPoly(proto.Message):
    r"""Normalized bounding polygon.
    Attributes:
        normalized_vertices (Sequence[google.cloud.datalabeling_v1beta1.types.NormalizedVertex]):
            The bounding polygon normalized vertices.
    """

    normalized_vertices = proto.RepeatedField(
        proto.MESSAGE, number=1, message="NormalizedVertex",
    )


class ImageBoundingPolyAnnotation(proto.Message):
    r"""Image bounding poly annotation. It represents a polygon
    including bounding box in the image.

    Attributes:
        bounding_poly (google.cloud.datalabeling_v1beta1.types.BoundingPoly):

        normalized_bounding_poly (google.cloud.datalabeling_v1beta1.types.NormalizedBoundingPoly):

        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            Label of object in this bounding polygon.
    """

    bounding_poly = proto.Field(
        proto.MESSAGE, number=2, oneof="bounded_area", message="BoundingPoly",
    )
    normalized_bounding_poly = proto.Field(
        proto.MESSAGE, number=3, oneof="bounded_area", message="NormalizedBoundingPoly",
    )
    annotation_spec = proto.Field(
        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
    )


class Polyline(proto.Message):
    r"""A line with multiple line segments.
    Attributes:
        vertices (Sequence[google.cloud.datalabeling_v1beta1.types.Vertex]):
            The polyline vertices.
    """

    vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="Vertex",)


class NormalizedPolyline(proto.Message):
    r"""Normalized polyline.
    Attributes:
        normalized_vertices (Sequence[google.cloud.datalabeling_v1beta1.types.NormalizedVertex]):
            The normalized polyline vertices.
    """

    normalized_vertices = proto.RepeatedField(
        proto.MESSAGE, number=1, message="NormalizedVertex",
    )


class ImagePolylineAnnotation(proto.Message):
    r"""A polyline for the image annotation.
    Attributes:
        polyline (google.cloud.datalabeling_v1beta1.types.Polyline):

        normalized_polyline (google.cloud.datalabeling_v1beta1.types.NormalizedPolyline):

        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            Label of this polyline.
    """

    polyline = proto.Field(proto.MESSAGE, number=2, oneof="poly", message="Polyline",)
    normalized_polyline = proto.Field(
        proto.MESSAGE, number=3, oneof="poly", message="NormalizedPolyline",
    )
    annotation_spec = proto.Field(
        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
    )


class ImageSegmentationAnnotation(proto.Message):
    r"""Image segmentation annotation.
    Attributes:
        annotation_colors (Sequence[google.cloud.datalabeling_v1beta1.types.ImageSegmentationAnnotation.AnnotationColorsEntry]):
            The mapping between rgb color and annotation
            spec. The key is the rgb color represented in
            format of rgb(0, 0, 0). The value is the
            AnnotationSpec.
        mime_type (str):
            Image format.
        image_bytes (bytes):
            A byte string of a full image's color map.
    """

    annotation_colors = proto.MapField(
        proto.STRING,
        proto.MESSAGE,
        number=1,
        message=annotation_spec_set.AnnotationSpec,
    )
    mime_type = proto.Field(proto.STRING, number=2,)
    image_bytes = proto.Field(proto.BYTES, number=3,)


class TextClassificationAnnotation(proto.Message):
    r"""Text classification annotation.
    Attributes:
        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            Label of the text.
    """

    annotation_spec = proto.Field(
        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
    )


class TextEntityExtractionAnnotation(proto.Message):
    r"""Text entity extraction annotation.
    Attributes:
        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            Label of the text entities.
        sequential_segment (google.cloud.datalabeling_v1beta1.types.SequentialSegment):
            Position of the entity.
    """

    annotation_spec = proto.Field(
        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
    )
    sequential_segment = proto.Field(
        proto.MESSAGE, number=2, message="SequentialSegment",
    )


class SequentialSegment(proto.Message):
    r"""Start and end position in a sequence (e.g. text segment).
    Attributes:
        start (int):
            Start position (inclusive).
        end (int):
            End position (exclusive).
    """

    start = proto.Field(proto.INT32, number=1,)
    end = proto.Field(proto.INT32, number=2,)


class TimeSegment(proto.Message):
    r"""A time period inside of an example that has a time dimension
    (e.g. video).

    Attributes:
        start_time_offset (google.protobuf.duration_pb2.Duration):
            Start of the time segment (inclusive),
            represented as the duration since the example
            start.
        end_time_offset (google.protobuf.duration_pb2.Duration):
            End of the time segment (exclusive),
            represented as the duration since the example
            start.
    """

    start_time_offset = proto.Field(
        proto.MESSAGE, number=1, message=duration_pb2.Duration,
    )
    end_time_offset = proto.Field(
        proto.MESSAGE, number=2, message=duration_pb2.Duration,
    )


class VideoClassificationAnnotation(proto.Message):
    r"""Video classification annotation.
    Attributes:
        time_segment (google.cloud.datalabeling_v1beta1.types.TimeSegment):
            The time segment of the video to which the
            annotation applies.
        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            Label of the segment specified by time_segment.
    """

    time_segment = proto.Field(proto.MESSAGE, number=1, message="TimeSegment",)
    annotation_spec = proto.Field(
        proto.MESSAGE, number=2, message=annotation_spec_set.AnnotationSpec,
    )


class ObjectTrackingFrame(proto.Message):
    r"""Video frame level annotation for object detection and
    tracking.

    Attributes:
        bounding_poly (google.cloud.datalabeling_v1beta1.types.BoundingPoly):

        normalized_bounding_poly (google.cloud.datalabeling_v1beta1.types.NormalizedBoundingPoly):

        time_offset (google.protobuf.duration_pb2.Duration):
            The time offset of this frame relative to the
            beginning of the video.
    """

    bounding_poly = proto.Field(
        proto.MESSAGE, number=1, oneof="bounded_area", message="BoundingPoly",
    )
    normalized_bounding_poly = proto.Field(
        proto.MESSAGE, number=2, oneof="bounded_area", message="NormalizedBoundingPoly",
    )
    time_offset = proto.Field(proto.MESSAGE, number=3, message=duration_pb2.Duration,)


class VideoObjectTrackingAnnotation(proto.Message):
    r"""Video object tracking annotation.
    Attributes:
        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            Label of the object tracked in this
            annotation.
        time_segment (google.cloud.datalabeling_v1beta1.types.TimeSegment):
            The time segment of the video to which object
            tracking applies.
        object_tracking_frames (Sequence[google.cloud.datalabeling_v1beta1.types.ObjectTrackingFrame]):
            The list of frames where this object track
            appears.
    """

    annotation_spec = proto.Field(
        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
    )
    time_segment = proto.Field(proto.MESSAGE, number=2, message="TimeSegment",)
    object_tracking_frames = proto.RepeatedField(
        proto.MESSAGE, number=3, message="ObjectTrackingFrame",
    )


class VideoEventAnnotation(proto.Message):
    r"""Video event annotation.
    Attributes:
        annotation_spec (google.cloud.datalabeling_v1beta1.types.AnnotationSpec):
            Label of the event in this annotation.
        time_segment (google.cloud.datalabeling_v1beta1.types.TimeSegment):
            The time segment of the video to which the
            annotation applies.
    """

    annotation_spec = proto.Field(
        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
    )
    time_segment = proto.Field(proto.MESSAGE, number=2, message="TimeSegment",)


class AnnotationMetadata(proto.Message):
    r"""Additional information associated with the annotation.
    Attributes:
        operator_metadata (google.cloud.datalabeling_v1beta1.types.OperatorMetadata):
            Metadata related to human labeling.
    """

    operator_metadata = proto.Field(
        proto.MESSAGE, number=2, message="OperatorMetadata",
    )


class OperatorMetadata(proto.Message):
    r"""General information useful for labels coming from
    contributors.

    Attributes:
        score (float):
            Confidence score corresponding to a label.
            For examle, if 3 contributors have answered the
            question and 2 of them agree on the final label,
            the confidence score will be 0.67 (2/3).
        total_votes (int):
            The total number of contributors that answer
            this question.
        label_votes (int):
            The total number of contributors that choose
            this label.
        comments (Sequence[str]):
            Comments from contributors.
    """

    score = proto.Field(proto.FLOAT, number=1,)
    total_votes = proto.Field(proto.INT32, number=2,)
    label_votes = proto.Field(proto.INT32, number=3,)
    comments = proto.RepeatedField(proto.STRING, number=4,)


__all__ = tuple(sorted(__protobuf__.manifest))
